@@ -14,7 +14,7 @@
 
   // on load, establish global delegations for now and future
   $(document).ready(function() {
-    var tab = '[% tab.tag %]'
+    var tab = '[% tab.tag | html_entity %]'
     var target = '#' + tab + '_pane';
 
     // sidebar form fields should change colour and have bin/copy icon
